==> ejc-quality-impl-3.0.0-20240312.094346-9-sources.jar: com/ejianc/business/inspect/bean/IdentifyDetailEntity.java <==
package com.ejianc.business.inspect.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 重大危险源动态辨识子实体
 *
 * @author generator
 *
 */
 @TableName("ejc_quality_identify_detail")
public class IdentifyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="identify_id")
    private Long identifyId; // 主表主键
    @TableField(value="danger_category")
    private String dangerCategory; // 危险源类别
    @TableField(value="work_area")
    private String workArea; // 作业区域
    @TableField(value="danger_name")
    private String dangerName; // 危险源名称
    @TableField(value="danger_level")
    private String dangerLevel; // 危险源级别
    @TableField(value="damage_type")
    private String damageType; // 伤害方式
    @TableField(value="crash_type")
    private String crashType; // 事故类型
    @TableField(value="l_evaluate")
    private BigDecimal lEvaluate; // l评价
    @TableField(value="e_evaluate")
    private BigDecimal eEvaluate; // e评价
    @TableField(value="c_evaluate")
    private BigDecimal cEvaluate; // c评价
    @TableField(value="d_evaluate")
    private BigDecimal dEvaluate; // d评价:D=L*E*C
    @TableField(value="risk_level")
    private String riskLevel; // 风险等级
    @TableField(value="color")
    private String color; // 颜色标识
    @TableField(value="res_person")
    private String resPerson; // 责任人
    @TableField(value="control_id")
    private Long controlId; // 档案ID
    @TableField(value="control_category")
    private String controlCategory; // 管控项目
    @TableField(value="control_measure")
    private String controlMeasure; // 管控措施
    @TableField(value="control_level")
    private String controlLevel; // 管控层级
    @TableField(value="memo")
    private String memo; // 备注




    public Long getIdentifyId() {
        return identifyId;
    }

    public void setIdentifyId(Long identifyId) {
        this.identifyId = identifyId;
    }
    public String getDangerCategory() {
        return dangerCategory;
    }

    public void setDangerCategory(String dangerCategory) {
        this.dangerCategory = dangerCategory;
    }
    public String getWorkArea() {
        return workArea;
    }

    public void setWorkArea(String workArea) {
        this.workArea = workArea;
    }
    public String getDangerName() {
        return dangerName;
    }

    public void setDangerName(String dangerName) {
        this.dangerName = dangerName;
    }
    public String getDangerLevel() {
        return dangerLevel;
    }

    public void setDangerLevel(String dangerLevel) {
        this.dangerLevel = dangerLevel;
    }
    public String getDamageType() {
        return damageType;
    }

    public void setDamageType(String damageType) {
        this.damageType = damageType;
    }
    public String getCrashType() {
        return crashType;
    }

    public void setCrashType(String crashType) {
        this.crashType = crashType;
    }
    public BigDecimal getLEvaluate() {
        return lEvaluate;
    }

    public void setLEvaluate(BigDecimal lEvaluate) {
        this.lEvaluate = lEvaluate;
    }
    public BigDecimal getEEvaluate() {
        return eEvaluate;
    }

    public void setEEvaluate(BigDecimal eEvaluate) {
        this.eEvaluate = eEvaluate;
    }
    public BigDecimal getCEvaluate() {
        return cEvaluate;
    }

    public void setCEvaluate(BigDecimal cEvaluate) {
        this.cEvaluate = cEvaluate;
    }
    public BigDecimal getDEvaluate() {
        return dEvaluate;
    }

    public void setDEvaluate(BigDecimal dEvaluate) {
        this.dEvaluate = dEvaluate;
    }
    public String getRiskLevel() {
        return riskLevel;
    }

    public void setRiskLevel(String riskLevel) {
        this.riskLevel = riskLevel;
    }
    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }
    public String getResPerson() {
        return resPerson;
    }

    public void setResPerson(String resPerson) {
        this.resPerson = resPerson;
    }
    public Long getControlId() {
        return controlId;
    }

    public void setControlId(Long controlId) {
        this.controlId = controlId;
    }
    public String getControlCategory() {
        return controlCategory;
    }

    public void setControlCategory(String controlCategory) {
        this.controlCategory = controlCategory;
    }
    public String getControlMeasure() {
        return controlMeasure;
    }

    public void setControlMeasure(String controlMeasure) {
        this.controlMeasure = controlMeasure;
    }
    public String getControlLevel() {
        return controlLevel;
    }

    public void setControlLevel(String controlLevel) {
        this.controlLevel = controlLevel;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-quality-impl-3.0.0-20240828.022529-87-sources.jar: com/ejianc/business/inspect/bean/IdentifyDetailEntity.java <==
package com.ejianc.business.inspect.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 重大危险源动态辨识子实体
 *
 * @author generator
 *
 */
 @TableName("ejc_quality_identify_detail")
public class IdentifyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="identify_id")
    private Long identifyId; // 主表主键
    @TableField(value="danger_category")
    private String dangerCategory; // 危险源类别
    @TableField(value="work_area")
    private String workArea; // 作业区域
    @TableField(value="danger_name")
    private String dangerName; // 危险源名称
    @TableField(value="danger_level")
    private String dangerLevel; // 危险源级别
    @TableField(value="damage_type")
    private String damageType; // 伤害方式
    @TableField(value="crash_type")
    private String crashType; // 事故类型
    @TableField(value="levaluate")
    private BigDecimal levaluate; // l评价
    @TableField(value="eevaluate")
    private BigDecimal eevaluate; // e评价
    @TableField(value="cevaluate")
    private BigDecimal cevaluate; // c评价
    @TableField(value="devaluate")
    private BigDecimal devaluate; // d评价:D=L*E*C
    @TableField(value="risk_level")
    private String riskLevel; // 风险等级
    @TableField(value="color")
    private String color; // 颜色标识
    @TableField(value="res_person")
    private String resPerson; // 责任人
    @TableField(value="control_id")
    private Long controlId; // 档案ID
    @TableField(value="control_category")
    private String controlCategory; // 管控项目
    @TableField(value="control_measure")
    private String controlMeasure; // 管控措施
    @TableField(value="control_level")
    private String controlLevel; // 管控层级
    @TableField(value="memo")
    private String memo; // 备注




    public Long getIdentifyId() {
        return identifyId;
    }

    public void setIdentifyId(Long identifyId) {
        this.identifyId = identifyId;
    }
    public String getDangerCategory() {
        return dangerCategory;
    }

    public void setDangerCategory(String dangerCategory) {
        this.dangerCategory = dangerCategory;
    }
    public String getWorkArea() {
        return workArea;
    }

    public void setWorkArea(String workArea) {
        this.workArea = workArea;
    }
    public String getDangerName() {
        return dangerName;
    }

    public void setDangerName(String dangerName) {
        this.dangerName = dangerName;
    }
    public String getDangerLevel() {
        return dangerLevel;
    }

    public void setDangerLevel(String dangerLevel) {
        this.dangerLevel = dangerLevel;
    }
    public String getDamageType() {
        return damageType;
    }

    public void setDamageType(String damageType) {
        this.damageType = damageType;
    }
    public String getCrashType() {
        return crashType;
    }

    public void setCrashType(String crashType) {
        this.crashType = crashType;
    }

    public BigDecimal getLevaluate() {
        return levaluate;
    }

    public void setLevaluate(BigDecimal levaluate) {
        this.levaluate = levaluate;
    }

    public BigDecimal getEevaluate() {
        return eevaluate;
    }

    public void setEevaluate(BigDecimal eevaluate) {
        this.eevaluate = eevaluate;
    }

    public BigDecimal getCevaluate() {
        return cevaluate;
    }

    public void setCevaluate(BigDecimal cevaluate) {
        this.cevaluate = cevaluate;
    }

    public BigDecimal getDevaluate() {
        return devaluate;
    }

    public void setDevaluate(BigDecimal devaluate) {
        this.devaluate = devaluate;
    }

    public String getRiskLevel() {
        return riskLevel;
    }

    public void setRiskLevel(String riskLevel) {
        this.riskLevel = riskLevel;
    }
    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }
    public String getResPerson() {
        return resPerson;
    }

    public void setResPerson(String resPerson) {
        this.resPerson = resPerson;
    }
    public Long getControlId() {
        return controlId;
    }

    public void setControlId(Long controlId) {
        this.controlId = controlId;
    }
    public String getControlCategory() {
        return controlCategory;
    }

    public void setControlCategory(String controlCategory) {
        this.controlCategory = controlCategory;
    }
    public String getControlMeasure() {
        return controlMeasure;
    }

    public void setControlMeasure(String controlMeasure) {
        this.controlMeasure = controlMeasure;
    }
    public String getControlLevel() {
        return controlLevel;
    }

    public void setControlLevel(String controlLevel) {
        this.controlLevel = controlLevel;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
